### Serena v1.0 Is Here!

April 3, 2026

After a full year of work since the first version of Serena, we are excited to announce the release of Serena v1.0!

Since our last update, we have now added support for exciting new retrieval and refactoring tools, especially for users of the JetBrains backend.

- safe_delete, jet_brains_safe_delete (beta):
  Safely deletes a symbol, checking for remaining usages first
- jet_brains_move (beta):
  Moves a symbol, file or directory to a new location, updating all references
- jet_brains_find_declaration:
  Finds the declaration of a symbol using the JetBrains backend
- jet_brains_find_implementations:
  Finds the implementations of a symbol (e.g. abstract method)
- jet_brains_inline_symbol (beta):
  Inlines a symbol, replacing all call sites with the symbol’s body

We are far from done. Many new features will be coming your way – for both the LSP and JetBrains backends.

Thank you to our contributors, users and customers!